<html id="html">
    <head id="head">
        <link href="https://fonts.googleapis.com/css?family=Cantarell" rel="stylesheet">
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
        <style>
             div {
                 text-align:left;
             }
             a.archive {
                 font-size:1.1em;
                 font-weight:bold;
             }
             .hash {
                 font-style:italic;
                 color:gray;
             }
             div.locales {
                 text-align:right;
             }
             div.license {
                 text-align:center;
                 font-size:0.8em;
             }
         </style>
    </head>
    <body>
        <h1 id="author">
            This is the author name
        </h1>
        <div id="sections">
        </div>
        <div id="contacts">
        </div>
        <div id="locales", class="locales">
        </div>
        <div id="license", class="license">
        </div>
    </body>
</html>
